==> pygmentize-0.3.0.tgz: package/lib/pygmentize.js <==
/*
 * pygmentize
 * https://github.com/rdworth/node-pygmentize
 *
 * Copyright (c) 2012 Richard D. Worth
 * Licensed under the MIT license.
 */

var jsdom = require( "jsdom" ),
	async = require( "async" ),
	spawn = require( "child_process" ).spawn;

function file( filename, callback ) {
	if (filename === undefined ) {
		throw new Error("pygmentize.file() requires a filename argument");
	}

	jsdom.env({
		html: filename,
		features: {
			QuerySelector: true
		},
		done: function(errors, window) {
			var document = window.document,
				highlight = document.querySelectorAll("pre > code"),
				htmlDecode = function( input ) {
					var e = document.createElement( "div" );
					e.innerHTML = input;
					return e.childNodes.length === 0 ? "" : e.childNodes[0].nodeValue;
				};

			async.forEachSeries( highlight, function( el, done ){
				var before = htmlDecode( el.innerHTML ),
					lang = el.getAttribute( "data-lang" ),
					linenos = el.getAttribute( "data-linenos" ),
					linenostart = el.getAttribute( "data-linenostart" )
					after = "",
					options = [];
				
				if ( !!lang ) {
					options.push( "-l", lang );
				} else {
					options.push( "-g" );
				}
				options.push( "-f", "html", "-O", "encoding=utf-8"
					+ ( linenos ? ",linenos=" + linenos : "" )
					+ ( linenostart ? ",linenostart=" + linenostart : "" )
				);

				var pygmentize = spawn( "pygmentize", options);
				pygmentize.stdout.on('data', function (data) {
					after += data;
				});
				pygmentize.stderr.on('data', function (data) {
					console.error('stderr: ' + data);
				});
				pygmentize.on('exit', function (code) {
					if ( code !== 0 ) {
						console.error('child process exited with code ' + code);
						done( new Error( code ) );
						return;
					}
					var div = document.createElement( "div" );
					div.innerHTML = after;
					if ( linenos ) {
						div.innerHTML = "<div class=\"highlightblock\">" + after + "</div>";
					} else {
						div.innerHTML = after;
					}
					el.parentNode.parentNode.replaceChild( div.childNodes[ 0 ], el.parentNode );
					done();
				});
				pygmentize.stdin.write( before );
				pygmentize.stdin.end();
			}, function( error ){
				callback( error, window.document.body.innerHTML );
			});
		}
	});

}

module.exports = {
	file: file
};

==> pygmentize-0.4.0.tgz: package/lib/pygmentize.js <==
/*
 * pygmentize
 * https://github.com/rdworth/node-pygmentize
 *
 * Copyright (c) 2012 Richard D. Worth
 * Licensed under the MIT license.
 */

var jsdom = require( "jsdom" ),
	async = require( "async" ),
	spawn = require( "child_process" ).spawn;

function file( filename, callback ) {
	if (filename === undefined ) {
		throw new Error("pygmentize.file() requires a filename argument");
	}

	jsdom.env({
		html: filename,
		features: {
			QuerySelector: true
		},
		done: function(errors, window) {
			var document = window.document,
				highlight = document.querySelectorAll("pre > code"),
				htmlDecode = function( input ) {
					var e = document.createElement( "div" );
					e.innerHTML = input;
					return e.childNodes.length === 0 ? "" : e.childNodes[0].nodeValue;
				};

			async.forEachSeries( highlight, function( el, done ){
				var before = htmlDecode( el.innerHTML ),
					lang = el.getAttribute( "data-lang" ),
					linenos = el.getAttribute( "data-linenos" ) || undefined,
					after = "",
					options = [];
				
				if ( !!lang ) {
					options.push( "-l", lang );
				} else {
					options.push( "-g" );
				}
				options.push( "-f", "html", "-O", "encoding=utf-8" +
					( linenos !== undefined ? ",linenos=" + linenos : "" ) +
					( linenos > -1 ? ",linenostart=" + linenos : "" )
				);

				var pygmentize = spawn( "pygmentize", options);
				pygmentize.stdout.on('data', function (data) {
					after += data;
				});
				pygmentize.stderr.on('data', function (data) {
					console.error('stderr: ' + data);
				});
				pygmentize.on('exit', function (code) {
					if ( code !== 0 ) {
						console.error('child process exited with code ' + code);
						done( new Error( code ) );
						return;
					}
					var div = document.createElement( "div" );
					div.innerHTML = after;
					if ( linenos ) {
						div.innerHTML = "<div class=\"highlightblock\">" + after + "</div>";
					} else {
						div.innerHTML = after;
					}
					el.parentNode.parentNode.replaceChild( div.childNodes[ 0 ], el.parentNode );
					done();
				});
				pygmentize.stdin.write( before );
				pygmentize.stdin.end();
			}, function( error ){
				callback( error, window.document.body.innerHTML );
			});
		}
	});

}

module.exports = {
	file: file
};
